@@ -6,9 +6,9 @@ Type annotations for compute-optimizer service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_compute_optimizer.literals import EBSFilterNameType
+    from mypy_boto3_compute_optimizer.literals import CpuVendorArchitectureType
 
-    data: EBSFilterNameType = "Finding"
+    data: CpuVendorArchitectureType = "AWS_ARM64"
     ```
 """
 import sys
@@ -20,9 +20,11 @@ else:
 
 
 __all__ = (
+    "CpuVendorArchitectureType",
     "EBSFilterNameType",
     "EBSFindingType",
     "EBSMetricNameType",
+    "EnrollmentFilterNameType",
     "ExportableAutoScalingGroupFieldType",
     "ExportableInstanceFieldType",
     "ExportableLambdaFunctionFieldType",
@@ -50,6 +52,7 @@ __all__ = (
 )
 
 
+CpuVendorArchitectureType = Literal["AWS_ARM64", "CURRENT"]
 EBSFilterNameType = Literal["Finding"]
 EBSFindingType = Literal["NotOptimized", "Optimized"]
 EBSMetricNameType = Literal[
@@ -58,6 +61,7 @@ EBSMetricNameType = Literal[
     "VolumeWriteBytesPerSecond",
     "VolumeWriteOpsPerSecond",
 ]
+EnrollmentFilterNameType = Literal["Status"]
 ExportableAutoScalingGroupFieldType = Literal[
     "AccountId",
     "AutoScalingGroupArn",
@@ -251,6 +255,7 @@ MetricNameType = Literal[
 ]
 MetricStatisticType = Literal["Average", "Maximum"]
 PlatformDifferenceType = Literal[
+    "Architecture",
     "Hypervisor",
     "InstanceStoreAvailability",
     "NetworkInterface",
