@@ -6,9 +6,9 @@ Type annotations for compute-optimizer service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_compute_optimizer.type_defs import AutoScalingGroupConfigurationTypeDef
+    from mypy_boto3_compute_optimizer.type_defs import AccountEnrollmentStatusTypeDef
 
-    data: AutoScalingGroupConfigurationTypeDef = {...}
+    data: AccountEnrollmentStatusTypeDef = {...}
     ```
 """
 import sys
@@ -16,6 +16,7 @@ from datetime import datetime
 from typing import Any, Dict, List, Union
 
 from .literals import (
+    CpuVendorArchitectureType,
     EBSFindingType,
     EBSMetricNameType,
     ExportableAutoScalingGroupFieldType,
@@ -53,6 +54,7 @@ else:
 
 
 __all__ = (
+    "AccountEnrollmentStatusTypeDef",
     "AutoScalingGroupConfigurationTypeDef",
     "AutoScalingGroupRecommendationOptionTypeDef",
     "AutoScalingGroupRecommendationTypeDef",
@@ -60,6 +62,7 @@ __all__ = (
     "DescribeRecommendationExportJobsResponseTypeDef",
     "EBSFilterTypeDef",
     "EBSUtilizationMetricTypeDef",
+    "EnrollmentFilterTypeDef",
     "ExportAutoScalingGroupRecommendationsRequestRequestTypeDef",
     "ExportAutoScalingGroupRecommendationsResponseTypeDef",
     "ExportDestinationTypeDef",
@@ -79,6 +82,8 @@ __all__ = (
     "GetEC2RecommendationProjectedMetricsRequestRequestTypeDef",
     "GetEC2RecommendationProjectedMetricsResponseTypeDef",
     "GetEnrollmentStatusResponseTypeDef",
+    "GetEnrollmentStatusesForOrganizationRequestRequestTypeDef",
+    "GetEnrollmentStatusesForOrganizationResponseTypeDef",
     "GetLambdaFunctionRecommendationsRequestRequestTypeDef",
     "GetLambdaFunctionRecommendationsResponseTypeDef",
     "GetRecommendationErrorTypeDef",
@@ -95,6 +100,7 @@ __all__ = (
     "ProjectedMetricTypeDef",
     "ReasonCodeSummaryTypeDef",
     "RecommendationExportJobTypeDef",
+    "RecommendationPreferencesTypeDef",
     "RecommendationSourceTypeDef",
     "RecommendationSummaryTypeDef",
     "RecommendedOptionProjectedMetricTypeDef",
@@ -110,6 +116,17 @@ __all__ = (
     "VolumeRecommendationTypeDef",
 )
 
+AccountEnrollmentStatusTypeDef = TypedDict(
+    "AccountEnrollmentStatusTypeDef",
+    {
+        "accountId": str,
+        "status": StatusType,
+        "statusReason": str,
+        "lastUpdatedTimestamp": datetime,
+    },
+    total=False,
+)
+
 AutoScalingGroupConfigurationTypeDef = TypedDict(
     "AutoScalingGroupConfigurationTypeDef",
     {
@@ -187,6 +204,15 @@ EBSUtilizationMetricTypeDef = TypedDict(
     total=False,
 )
 
+EnrollmentFilterTypeDef = TypedDict(
+    "EnrollmentFilterTypeDef",
+    {
+        "name": Literal["Status"],
+        "values": List[str],
+    },
+    total=False,
+)
+
 _RequiredExportAutoScalingGroupRecommendationsRequestRequestTypeDef = TypedDict(
     "_RequiredExportAutoScalingGroupRecommendationsRequestRequestTypeDef",
     {
@@ -201,6 +227,7 @@ _OptionalExportAutoScalingGroupRecommendationsRequestRequestTypeDef = TypedDict(
         "fieldsToExport": List[ExportableAutoScalingGroupFieldType],
         "fileFormat": Literal["Csv"],
         "includeMemberAccounts": bool,
+        "recommendationPreferences": "RecommendationPreferencesTypeDef",
     },
     total=False,
 )
@@ -279,6 +306,7 @@ _OptionalExportEC2InstanceRecommendationsRequestRequestTypeDef = TypedDict(
         "fieldsToExport": List[ExportableInstanceFieldType],
         "fileFormat": Literal["Csv"],
         "includeMemberAccounts": bool,
+        "recommendationPreferences": "RecommendationPreferencesTypeDef",
     },
     total=False,
 )
@@ -352,6 +380,7 @@ GetAutoScalingGroupRecommendationsRequestRequestTypeDef = TypedDict(
         "nextToken": str,
         "maxResults": int,
         "filters": List["FilterTypeDef"],
+        "recommendationPreferences": "RecommendationPreferencesTypeDef",
     },
     total=False,
 )
@@ -396,6 +425,7 @@ GetEC2InstanceRecommendationsRequestRequestTypeDef = TypedDict(
         "maxResults": int,
         "filters": List["FilterTypeDef"],
         "accountIds": List[str],
+        "recommendationPreferences": "RecommendationPreferencesTypeDef",
     },
     total=False,
 )
@@ -410,8 +440,8 @@ GetEC2InstanceRecommendationsResponseTypeDef = TypedDict(
     },
 )
 
-GetEC2RecommendationProjectedMetricsRequestRequestTypeDef = TypedDict(
-    "GetEC2RecommendationProjectedMetricsRequestRequestTypeDef",
+_RequiredGetEC2RecommendationProjectedMetricsRequestRequestTypeDef = TypedDict(
+    "_RequiredGetEC2RecommendationProjectedMetricsRequestRequestTypeDef",
     {
         "instanceArn": str,
         "stat": MetricStatisticType,
@@ -420,6 +450,21 @@ GetEC2RecommendationProjectedMetricsRequestRequestTypeDef = TypedDict(
         "endTime": Union[datetime, str],
     },
 )
+_OptionalGetEC2RecommendationProjectedMetricsRequestRequestTypeDef = TypedDict(
+    "_OptionalGetEC2RecommendationProjectedMetricsRequestRequestTypeDef",
+    {
+        "recommendationPreferences": "RecommendationPreferencesTypeDef",
+    },
+    total=False,
+)
+
+
+class GetEC2RecommendationProjectedMetricsRequestRequestTypeDef(
+    _RequiredGetEC2RecommendationProjectedMetricsRequestRequestTypeDef,
+    _OptionalGetEC2RecommendationProjectedMetricsRequestRequestTypeDef,
+):
+    pass
+
 
 GetEC2RecommendationProjectedMetricsResponseTypeDef = TypedDict(
     "GetEC2RecommendationProjectedMetricsResponseTypeDef",
@@ -435,6 +480,27 @@ GetEnrollmentStatusResponseTypeDef = TypedDict(
         "status": StatusType,
         "statusReason": str,
         "memberAccountsEnrolled": bool,
+        "lastUpdatedTimestamp": datetime,
+        "numberOfMemberAccountsOptedIn": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetEnrollmentStatusesForOrganizationRequestRequestTypeDef = TypedDict(
+    "GetEnrollmentStatusesForOrganizationRequestRequestTypeDef",
+    {
+        "filters": List["EnrollmentFilterTypeDef"],
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
+GetEnrollmentStatusesForOrganizationResponseTypeDef = TypedDict(
+    "GetEnrollmentStatusesForOrganizationResponseTypeDef",
+    {
+        "accountEnrollmentStatuses": List["AccountEnrollmentStatusTypeDef"],
+        "nextToken": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -618,6 +684,14 @@ RecommendationExportJobTypeDef = TypedDict(
     total=False,
 )
 
+RecommendationPreferencesTypeDef = TypedDict(
+    "RecommendationPreferencesTypeDef",
+    {
+        "cpuVendorArchitectures": List[CpuVendorArchitectureType],
+    },
+    total=False,
+)
+
 RecommendationSourceTypeDef = TypedDict(
     "RecommendationSourceTypeDef",
     {
